.. JSONManipulator documentation master file, created by
   sphinx-quickstart on Tue Jul 14 10:07:10 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to JSONManipulator's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
